@@ -1,10 +1,12 @@
 from httplib import HTTPConnection
-from datetime import datetime
+from datetime import datetime, timedelta
+from urlparse import parse_qs
 
 from django.db import models
 from django.utils.translation import ugettext as _
 
 from fandjango.utils import cached_property as cached
+from fandjango.settings import FACEBOOK_APPLICATION_ID, FACEBOOK_APPLICATION_SECRET_KEY
 
 from facepy import GraphAPI
 
@@ -170,6 +172,22 @@ class User(models.Model):
         """
         return self.graph.get('me').get('verified', None)
 
+    @property
+    def permissions(self):
+        """
+        A list of strings describing `permissions`_ the user has granted your application.
+
+        .. _permissions: http://developers.facebook.com/docs/reference/api/permissions/
+        """
+        records = self.graph.get('me/permissions')['data'][0]
+
+        permissions = []
+        for permission, status in records.items():
+            if status:
+                permissions.append(permission)
+
+        return permissions
+
     @property
     def graph(self):
         """
@@ -200,7 +218,7 @@ class User(models.Model):
             return u'%s' % self.facebook_username
         else:
             return u'%s' % self.facebook_id
-            
+
     class Meta:
         verbose_name = _('user')
         verbose_name_plural = _('users')
@@ -213,10 +231,10 @@ class OAuthToken(models.Model):
 
     token = models.TextField(_('token'))
     """A string describing the OAuth token itself."""
-    
+
     issued_at = models.DateTimeField(_('issued at'))
     """A ``datetime`` object describing when the token was issued."""
-    
+
     expires_at = models.DateTimeField(_('expires at'), null=True, blank=True)
     """A ``datetime`` object describing when the token expires (or ``None`` if it doesn't)"""
 
@@ -224,6 +242,24 @@ class OAuthToken(models.Model):
     def expired(self):
         return self.expires_at < datetime.now() if self.expires_at else False
 
+    def extend(self):
+        """Extend the OAuth token."""
+        graph = GraphAPI()
+
+        response = graph.get('oauth/access_token',
+            client_id = FACEBOOK_APPLICATION_ID,
+            client_secret = FACEBOOK_APPLICATION_SECRET_KEY,
+            grant_type = 'fb_exchange_token',
+            fb_exchange_token = self.token
+        )
+
+        components = parse_qs(response)
+
+        self.token = components['access_token'][0]
+        self.expires_at = datetime.now() + timedelta(seconds = int(components['expires'][0]))
+
+        self.save()
+
     class Meta:
         verbose_name = _('OAuth token')
         verbose_name_plural = _('OAuth tokens')
