@@ -4,5 +4,5 @@ from views import *
 
 urlpatterns = patterns('',
     url(r'^authorize_application.html$', authorize_application, name='authorize_application'),
-    url(r'^deauthorize_application.html$', deauthorize_application)
+    url(r'^deauthorize_application.html$', deauthorize_application, name='deauthorize_application')
 )
\ No newline at end of file
